package com.xxl.job.admin.controller.custom;

import javax.annotation.Resource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.persagy.common.constant.CommonConstant;
import com.persagy.common.utils.StringUtil;
import com.xxl.job.admin.core.model.XxlJobInfo;
import com.xxl.job.admin.core.thread.JobTriggerPoolHelper;
import com.xxl.job.admin.core.trigger.TriggerTypeEnum;
import com.xxl.job.admin.service.XxlJobService;
import com.xxl.job.core.biz.model.ReturnT;

import io.swagger.annotations.Api;
import io.swagger.v3.oas.annotations.parameters.RequestBody;

/**
 * 暴露接口
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021年9月24日 下午2:37:55
 */
@RestController
@Api(tags = "任务触发点设置")
@RequestMapping(value = "/customInfo", method = {RequestMethod.POST})
public class CustomInfoController {

	@Resource
	private XxlJobService xxlJobService;
	
	@Autowired
	private CustomInfoHandler customInfoHandler;
	
	@RequestMapping(value = "/transfer")
	public ReturnT<String> transfer() {
		return customInfoHandler.transfer();
	}
	
	@RequestMapping(value = "/addOrUpdateAndStart")
	public ReturnT<String> addOrUpdateAndStart(@RequestBody XxlJobInfo jobInfo) {
		if (jobInfo.getId() == null) {
			xxlJobService.add(jobInfo);
		} else {
			xxlJobService.update(jobInfo);
		}
		// 启动任务
		return xxlJobService.start(jobInfo.getId());
	}
	
	@RequestMapping(value = "/add")
	public ReturnT<String> add(@RequestBody XxlJobInfo jobInfo) {
		return xxlJobService.add(jobInfo);
	}
	
	@RequestMapping(value = "/update")
	public ReturnT<String> update(@RequestBody XxlJobInfo jobInfo) {
		return xxlJobService.update(jobInfo);
	}
	
	@RequestMapping(value = "/remove")
	public ReturnT<String> remove(@RequestBody XxlJobInfo jobInfo) {
		return xxlJobService.remove(jobInfo.getId());
	}
	
	@RequestMapping(value = "/stop")
	public ReturnT<String> pause(@RequestBody XxlJobInfo jobInfo) {
		return xxlJobService.stop(jobInfo.getId());
	}
	
	@RequestMapping(value = "/start")
	public ReturnT<String> start(@RequestBody XxlJobInfo jobInfo) {
		return xxlJobService.start(jobInfo.getId());
	}
	
	@RequestMapping(value = "/trigger")
	public ReturnT<String> triggerJob(@RequestBody XxlJobInfo jobInfo) {
		String executorParam = jobInfo.getExecutorParam();
		if (StringUtil.isBlank(executorParam)) {
			executorParam = CommonConstant.EMPTY;
		}

		JobTriggerPoolHelper.trigger(jobInfo.getId(), TriggerTypeEnum.MANUAL, -1, null, executorParam, jobInfo.getAddressList());
		return ReturnT.SUCCESS;
	}
	
}
